Overview
========

This library simulates the process of a board game. The goal of the simulation is to predict the game 
process statistics depending on various parameters. From this, we can conclude which parameters are 
desirable to set in order to play effectively in a real game.

For more detail, read the documention in `here <https://robotic-board-game.readthedocs.io/en/latest/>`_.

Installation
============

Simply install with :code:`pip`:

.. code-block:: console

    pip install rbgame


If you want to animate the game with pre-trained models, please follow steps in our documentions.




